Class: Google::Cloud::Kms::Inventory::V1::KeyTrackingService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::Inventory::V1::KeyTrackingService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/kms/inventory/v1/key_tracking_service/rest/client.rb
Overview
REST client for the KeyTrackingService service.
Returns information about the resources in an org that are protected by a given Cloud KMS key via CMEK.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the KeyTrackingService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the KeyTrackingService Client instance.
-
#get_protected_resources_summary(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Kms::Inventory::V1::ProtectedResourcesSummary
Returns aggregate information about the resources protected by the given Cloud KMS CryptoKey.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new KeyTrackingService REST client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#search_protected_resources(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::Inventory::V1::ProtectedResource>
Returns metadata about the resources protected by the given Cloud KMS CryptoKey in the given Cloud organization/project.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#organization_path, #project_path, #protected_resources_summary_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new KeyTrackingService REST client object.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/google/cloud/kms/inventory/v1/key_tracking_service/rest/client.rb', line 132 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @key_tracking_service_stub = ::Google::Cloud::Kms::Inventory::V1::KeyTrackingService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @key_tracking_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the KeyTrackingService Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/cloud/kms/inventory/v1/key_tracking_service/rest/client.rb', line 66 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Kms", "Inventory", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.get_protected_resources_summary.timeout = 60.0 default_config.rpcs.search_protected_resources.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the KeyTrackingService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
102 103 104 105 |
# File 'lib/google/cloud/kms/inventory/v1/key_tracking_service/rest/client.rb', line 102 def configure yield @config if block_given? @config end |
#get_protected_resources_summary(request, options = nil) ⇒ ::Google::Cloud::Kms::Inventory::V1::ProtectedResourcesSummary #get_protected_resources_summary(name: nil, fallback_scope: nil) ⇒ ::Google::Cloud::Kms::Inventory::V1::ProtectedResourcesSummary
Returns aggregate information about the resources protected by the given
Cloud KMS CryptoKey. By default,
summary of resources within the same Cloud organization as the key will be
returned, which requires the KMS organization service account to be
configured(refer
https://docs.cloud.google.com/kms/docs/view-key-usage#required-roles).
If the KMS organization service account is not configured or key's project
is not part of an organization, set
fallback_scope
to FALLBACK_SCOPE_PROJECT to retrieve a summary of protected resources
within the key's project.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/google/cloud/kms/inventory/v1/key_tracking_service/rest/client.rb', line 242 def get_protected_resources_summary request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::Inventory::V1::GetProtectedResourcesSummaryRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_protected_resources_summary..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::Inventory::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_protected_resources_summary.timeout, metadata: , retry_policy: @config.rpcs.get_protected_resources_summary.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @key_tracking_service_stub.get_protected_resources_summary request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
179 180 181 |
# File 'lib/google/cloud/kms/inventory/v1/key_tracking_service/rest/client.rb', line 179 def logger @key_tracking_service_stub.logger end |
#search_protected_resources(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::Inventory::V1::ProtectedResource> #search_protected_resources(scope: nil, crypto_key: nil, page_size: nil, page_token: nil, resource_types: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Kms::Inventory::V1::ProtectedResource>
Returns metadata about the resources protected by the given Cloud KMS CryptoKey in the given Cloud organization/project.
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/google/cloud/kms/inventory/v1/key_tracking_service/rest/client.rb', line 364 def search_protected_resources request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Kms::Inventory::V1::SearchProtectedResourcesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.search_protected_resources..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Kms::Inventory::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.search_protected_resources.timeout, metadata: , retry_policy: @config.rpcs.search_protected_resources.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @key_tracking_service_stub.search_protected_resources request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @key_tracking_service_stub, :search_protected_resources, "protected_resources", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
112 113 114 |
# File 'lib/google/cloud/kms/inventory/v1/key_tracking_service/rest/client.rb', line 112 def universe_domain @key_tracking_service_stub.universe_domain end |