Class: Google::Cloud::Kms::Inventory::V1::ProtectedResource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb

Overview

Metadata about a resource protected by a Cloud KMS key.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_product::String

Returns The Cloud product that owns the resource. Example: compute.

Returns:

  • (::String)

    The Cloud product that owns the resource. Example: compute



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which this resource was created. The granularity is in seconds. Timestamp.nanos will always be 0.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time at which this resource was created. The granularity is in seconds. Timestamp.nanos will always be 0.



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#crypto_key_version::String

Returns The name of the Cloud KMS CryptoKeyVersion used to protect this resource via CMEK. This field is empty if the Google Cloud product owning the resource does not provide key version data to Asset Inventory. If there are multiple key versions protecting the resource, then this is same value as the first element of crypto_key_versions.

Returns:

  • (::String)

    The name of the Cloud KMS CryptoKeyVersion used to protect this resource via CMEK. This field is empty if the Google Cloud product owning the resource does not provide key version data to Asset Inventory. If there are multiple key versions protecting the resource, then this is same value as the first element of crypto_key_versions.



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#crypto_key_versions::Array<::String>

Returns The names of the Cloud KMS CryptoKeyVersion used to protect this resource via CMEK. This field is empty if the Google Cloud product owning the resource does not provide key versions data to Asset Inventory. The first element of this field is stored in crypto_key_version.

Returns:

  • (::Array<::String>)

    The names of the Cloud KMS CryptoKeyVersion used to protect this resource via CMEK. This field is empty if the Google Cloud product owning the resource does not provide key versions data to Asset Inventory. The first element of this field is stored in crypto_key_version.



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns A key-value pair of the resource's labels (v1) to their values.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A key-value pair of the resource's labels (v1) to their values.



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#location::String

Returns Location can be global, regional like us-east1, or zonal like us-west1-b.

Returns:

  • (::String)

    Location can be global, regional like us-east1, or zonal like us-west1-b.



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns The full resource name of the resource. Example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1.

Returns:

  • (::String)

    The full resource name of the resource. Example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1.



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#project::String

Returns Format: projects/{PROJECT_NUMBER}.

Returns:

  • (::String)

    Format: projects/{PROJECT_NUMBER}.



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#project_id::String

Returns The ID of the project that owns the resource.

Returns:

  • (::String)

    The ID of the project that owns the resource.



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#resource_type::String

Returns Example: compute.googleapis.com/Disk.

Returns:

  • (::String)

    Example: compute.googleapis.com/Disk



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 215

class ProtectedResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end