Module: Google::Cloud::Kms::Inventory::V1::Warning::WarningCode

Defined in:
proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb

Overview

Different types of warnings that can be returned to the user. The display_message contains detailed information regarding the warning_code.

Constant Summary collapse

WARNING_CODE_UNSPECIFIED =

Default value. This value is unused.

0
INSUFFICIENT_PERMISSIONS_PARTIAL_DATA =

Indicates that the caller or service agent lacks necessary permissions to view some of the requested data. The response may be partial. Example:

  • KMS organization service agent {service_agent_name} lacks the cloudasset.assets.searchAllResources permission on the scope.
1
RESOURCE_LIMIT_EXCEEDED_PARTIAL_DATA =

Indicates that a resource limit has been exceeded, resulting in partial data. Example:

  • The project has more than 10,000 assets (resources, crypto keys, key handles, IAM policies, etc).
2
ORG_LESS_PROJECT_PARTIAL_DATA =

Indicates that the project exists outside of an organization resource. Thus the analysis is only done for the project level data and results might be partial.

3