Class: Google::Cloud::Kms::V1::KeyAccessJustificationsPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/resources.rb

Overview

A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason values for encrypt, decrypt, and sign operations on a CryptoKey or [KeyAccessJustificationsPolicyConfig]google.cloud.kms.v1.KeyAccessJustificationsPolicyConfig.

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_access_reasons::Array<::Google::Cloud::Kms::V1::AccessReason>

Returns The list of allowed reasons for access to a CryptoKey. Note that empty allowed_access_reasons has a different meaning depending on where this message appears. If this is under [KeyAccessJustificationsPolicyConfig][google.cloud.kms.v1.KeyAccessJustificationsPolicyConfig], it means allow-all. If this is under CryptoKey, it means deny-all.

Returns:

  • (::Array<::Google::Cloud::Kms::V1::AccessReason>)

    The list of allowed reasons for access to a CryptoKey. Note that empty allowed_access_reasons has a different meaning depending on where this message appears. If this is under [KeyAccessJustificationsPolicyConfig][google.cloud.kms.v1.KeyAccessJustificationsPolicyConfig], it means allow-all. If this is under CryptoKey, it means deny-all.



1047
1048
1049
1050
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 1047

class KeyAccessJustificationsPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end