Class: Google::Cloud::Kms::V1::PublicKey

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/resources.rb

Overview

The public keys for a given CryptoKeyVersion. Obtained via [GetPublicKey][google.cloud.kms.v1.KeyManagementService.GetPublicKey].

Defined Under Namespace

Modules: PublicKeyFormat

Instance Attribute Summary collapse

Instance Attribute Details

#algorithm::Google::Cloud::Kms::V1::CryptoKeyVersion::CryptoKeyVersionAlgorithm

Returns The Algorithm associated with this key.



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 781

class PublicKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The supported {::Google::Cloud::Kms::V1::PublicKey PublicKey} formats.
  module PublicKeyFormat
    # If the
    # [public_key_format][google.cloud.kms.v1.GetPublicKeyRequest.public_key_format]
    # field is not specified:
    # - For PQC algorithms, an error will be returned.
    # - For non-PQC algorithms, the default format is PEM, and the field
    #   {::Google::Cloud::Kms::V1::PublicKey#pem pem} will be populated.
    #
    # Otherwise, the public key will be exported through the
    # {::Google::Cloud::Kms::V1::PublicKey#public_key public_key} field in the
    # requested format.
    PUBLIC_KEY_FORMAT_UNSPECIFIED = 0

    # The returned public key will be encoded in PEM format.
    # See the [RFC7468](https://tools.ietf.org/html/rfc7468) sections for
    # [General Considerations](https://tools.ietf.org/html/rfc7468#section-2)
    # and [Textual Encoding of Subject Public Key Info]
    # (https://tools.ietf.org/html/rfc7468#section-13) for more information.
    PEM = 1

    # The returned public key will be encoded in DER format (the
    # PrivateKeyInfo structure from RFC 5208).
    DER = 2

    # This is supported only for PQC algorithms.
    # The key material is returned in the format defined by NIST PQC
    # standards (FIPS 203, FIPS 204, and FIPS 205).
    NIST_PQC = 3

    # The returned public key is in raw bytes format defined in its standard
    # https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
    XWING_RAW_BYTES = 4
  end
end

#name::String

Returns The name of the CryptoKeyVersion public key. Provided here for verification.

NOTE: This field is in Beta.

Returns:

  • (::String)

    The name of the CryptoKeyVersion public key. Provided here for verification.

    NOTE: This field is in Beta.



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 781

class PublicKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The supported {::Google::Cloud::Kms::V1::PublicKey PublicKey} formats.
  module PublicKeyFormat
    # If the
    # [public_key_format][google.cloud.kms.v1.GetPublicKeyRequest.public_key_format]
    # field is not specified:
    # - For PQC algorithms, an error will be returned.
    # - For non-PQC algorithms, the default format is PEM, and the field
    #   {::Google::Cloud::Kms::V1::PublicKey#pem pem} will be populated.
    #
    # Otherwise, the public key will be exported through the
    # {::Google::Cloud::Kms::V1::PublicKey#public_key public_key} field in the
    # requested format.
    PUBLIC_KEY_FORMAT_UNSPECIFIED = 0

    # The returned public key will be encoded in PEM format.
    # See the [RFC7468](https://tools.ietf.org/html/rfc7468) sections for
    # [General Considerations](https://tools.ietf.org/html/rfc7468#section-2)
    # and [Textual Encoding of Subject Public Key Info]
    # (https://tools.ietf.org/html/rfc7468#section-13) for more information.
    PEM = 1

    # The returned public key will be encoded in DER format (the
    # PrivateKeyInfo structure from RFC 5208).
    DER = 2

    # This is supported only for PQC algorithms.
    # The key material is returned in the format defined by NIST PQC
    # standards (FIPS 203, FIPS 204, and FIPS 205).
    NIST_PQC = 3

    # The returned public key is in raw bytes format defined in its standard
    # https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
    XWING_RAW_BYTES = 4
  end
end

#pem::String

Returns The public key, encoded in PEM format. For more information, see the RFC 7468 sections for General Considerations and Textual Encoding of Subject Public Key Info.

Returns:



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 781

class PublicKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The supported {::Google::Cloud::Kms::V1::PublicKey PublicKey} formats.
  module PublicKeyFormat
    # If the
    # [public_key_format][google.cloud.kms.v1.GetPublicKeyRequest.public_key_format]
    # field is not specified:
    # - For PQC algorithms, an error will be returned.
    # - For non-PQC algorithms, the default format is PEM, and the field
    #   {::Google::Cloud::Kms::V1::PublicKey#pem pem} will be populated.
    #
    # Otherwise, the public key will be exported through the
    # {::Google::Cloud::Kms::V1::PublicKey#public_key public_key} field in the
    # requested format.
    PUBLIC_KEY_FORMAT_UNSPECIFIED = 0

    # The returned public key will be encoded in PEM format.
    # See the [RFC7468](https://tools.ietf.org/html/rfc7468) sections for
    # [General Considerations](https://tools.ietf.org/html/rfc7468#section-2)
    # and [Textual Encoding of Subject Public Key Info]
    # (https://tools.ietf.org/html/rfc7468#section-13) for more information.
    PEM = 1

    # The returned public key will be encoded in DER format (the
    # PrivateKeyInfo structure from RFC 5208).
    DER = 2

    # This is supported only for PQC algorithms.
    # The key material is returned in the format defined by NIST PQC
    # standards (FIPS 203, FIPS 204, and FIPS 205).
    NIST_PQC = 3

    # The returned public key is in raw bytes format defined in its standard
    # https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
    XWING_RAW_BYTES = 4
  end
end

#pem_crc32c::Google::Protobuf::Int64Value

Returns Integrity verification field. A CRC32C checksum of the returned PublicKey.pem. An integrity check of PublicKey.pem can be performed by computing the CRC32C checksum of PublicKey.pem and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

NOTE: This field is in Beta.

Returns:

  • (::Google::Protobuf::Int64Value)

    Integrity verification field. A CRC32C checksum of the returned PublicKey.pem. An integrity check of PublicKey.pem can be performed by computing the CRC32C checksum of PublicKey.pem and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

    NOTE: This field is in Beta.



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 781

class PublicKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The supported {::Google::Cloud::Kms::V1::PublicKey PublicKey} formats.
  module PublicKeyFormat
    # If the
    # [public_key_format][google.cloud.kms.v1.GetPublicKeyRequest.public_key_format]
    # field is not specified:
    # - For PQC algorithms, an error will be returned.
    # - For non-PQC algorithms, the default format is PEM, and the field
    #   {::Google::Cloud::Kms::V1::PublicKey#pem pem} will be populated.
    #
    # Otherwise, the public key will be exported through the
    # {::Google::Cloud::Kms::V1::PublicKey#public_key public_key} field in the
    # requested format.
    PUBLIC_KEY_FORMAT_UNSPECIFIED = 0

    # The returned public key will be encoded in PEM format.
    # See the [RFC7468](https://tools.ietf.org/html/rfc7468) sections for
    # [General Considerations](https://tools.ietf.org/html/rfc7468#section-2)
    # and [Textual Encoding of Subject Public Key Info]
    # (https://tools.ietf.org/html/rfc7468#section-13) for more information.
    PEM = 1

    # The returned public key will be encoded in DER format (the
    # PrivateKeyInfo structure from RFC 5208).
    DER = 2

    # This is supported only for PQC algorithms.
    # The key material is returned in the format defined by NIST PQC
    # standards (FIPS 203, FIPS 204, and FIPS 205).
    NIST_PQC = 3

    # The returned public key is in raw bytes format defined in its standard
    # https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
    XWING_RAW_BYTES = 4
  end
end

#protection_level::Google::Cloud::Kms::V1::ProtectionLevel

Returns The ProtectionLevel of the CryptoKeyVersion public key.



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 781

class PublicKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The supported {::Google::Cloud::Kms::V1::PublicKey PublicKey} formats.
  module PublicKeyFormat
    # If the
    # [public_key_format][google.cloud.kms.v1.GetPublicKeyRequest.public_key_format]
    # field is not specified:
    # - For PQC algorithms, an error will be returned.
    # - For non-PQC algorithms, the default format is PEM, and the field
    #   {::Google::Cloud::Kms::V1::PublicKey#pem pem} will be populated.
    #
    # Otherwise, the public key will be exported through the
    # {::Google::Cloud::Kms::V1::PublicKey#public_key public_key} field in the
    # requested format.
    PUBLIC_KEY_FORMAT_UNSPECIFIED = 0

    # The returned public key will be encoded in PEM format.
    # See the [RFC7468](https://tools.ietf.org/html/rfc7468) sections for
    # [General Considerations](https://tools.ietf.org/html/rfc7468#section-2)
    # and [Textual Encoding of Subject Public Key Info]
    # (https://tools.ietf.org/html/rfc7468#section-13) for more information.
    PEM = 1

    # The returned public key will be encoded in DER format (the
    # PrivateKeyInfo structure from RFC 5208).
    DER = 2

    # This is supported only for PQC algorithms.
    # The key material is returned in the format defined by NIST PQC
    # standards (FIPS 203, FIPS 204, and FIPS 205).
    NIST_PQC = 3

    # The returned public key is in raw bytes format defined in its standard
    # https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
    XWING_RAW_BYTES = 4
  end
end

#public_key::Google::Cloud::Kms::V1::ChecksummedData

Returns This field contains the public key (with integrity verification), formatted according to the public_key_format field.

Returns:



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 781

class PublicKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The supported {::Google::Cloud::Kms::V1::PublicKey PublicKey} formats.
  module PublicKeyFormat
    # If the
    # [public_key_format][google.cloud.kms.v1.GetPublicKeyRequest.public_key_format]
    # field is not specified:
    # - For PQC algorithms, an error will be returned.
    # - For non-PQC algorithms, the default format is PEM, and the field
    #   {::Google::Cloud::Kms::V1::PublicKey#pem pem} will be populated.
    #
    # Otherwise, the public key will be exported through the
    # {::Google::Cloud::Kms::V1::PublicKey#public_key public_key} field in the
    # requested format.
    PUBLIC_KEY_FORMAT_UNSPECIFIED = 0

    # The returned public key will be encoded in PEM format.
    # See the [RFC7468](https://tools.ietf.org/html/rfc7468) sections for
    # [General Considerations](https://tools.ietf.org/html/rfc7468#section-2)
    # and [Textual Encoding of Subject Public Key Info]
    # (https://tools.ietf.org/html/rfc7468#section-13) for more information.
    PEM = 1

    # The returned public key will be encoded in DER format (the
    # PrivateKeyInfo structure from RFC 5208).
    DER = 2

    # This is supported only for PQC algorithms.
    # The key material is returned in the format defined by NIST PQC
    # standards (FIPS 203, FIPS 204, and FIPS 205).
    NIST_PQC = 3

    # The returned public key is in raw bytes format defined in its standard
    # https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
    XWING_RAW_BYTES = 4
  end
end

#public_key_format::Google::Cloud::Kms::V1::PublicKey::PublicKeyFormat

Returns The PublicKey format specified by the customer through the [public_key_format][google.cloud.kms.v1.GetPublicKeyRequest.public_key_format] field.

Returns:



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 781

class PublicKey
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The supported {::Google::Cloud::Kms::V1::PublicKey PublicKey} formats.
  module PublicKeyFormat
    # If the
    # [public_key_format][google.cloud.kms.v1.GetPublicKeyRequest.public_key_format]
    # field is not specified:
    # - For PQC algorithms, an error will be returned.
    # - For non-PQC algorithms, the default format is PEM, and the field
    #   {::Google::Cloud::Kms::V1::PublicKey#pem pem} will be populated.
    #
    # Otherwise, the public key will be exported through the
    # {::Google::Cloud::Kms::V1::PublicKey#public_key public_key} field in the
    # requested format.
    PUBLIC_KEY_FORMAT_UNSPECIFIED = 0

    # The returned public key will be encoded in PEM format.
    # See the [RFC7468](https://tools.ietf.org/html/rfc7468) sections for
    # [General Considerations](https://tools.ietf.org/html/rfc7468#section-2)
    # and [Textual Encoding of Subject Public Key Info]
    # (https://tools.ietf.org/html/rfc7468#section-13) for more information.
    PEM = 1

    # The returned public key will be encoded in DER format (the
    # PrivateKeyInfo structure from RFC 5208).
    DER = 2

    # This is supported only for PQC algorithms.
    # The key material is returned in the format defined by NIST PQC
    # standards (FIPS 203, FIPS 204, and FIPS 205).
    NIST_PQC = 3

    # The returned public key is in raw bytes format defined in its standard
    # https://datatracker.ietf.org/doc/draft-connolly-cfrg-xwing-kem.
    XWING_RAW_BYTES = 4
  end
end