Class: Google::Cloud::Kms::V1::RetiredResource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/kms/v1/resources.rb

Overview

A RetiredResource resource represents the record of a deleted CryptoKey. Its purpose is to provide visibility into retained user data and to prevent reuse of these names for new CryptoKeys.

Instance Attribute Summary collapse

Instance Attribute Details

#delete_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which the original resource was deleted and this RetiredResource record was created.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time at which the original resource was deleted and this RetiredResource record was created.



1073
1074
1075
1076
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 1073

class RetiredResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String (readonly)

Returns Output only. Identifier. The resource name for this RetiredResource in the format projects/*/locations/*/retiredResources/*.

Returns:

  • (::String)

    Output only. Identifier. The resource name for this RetiredResource in the format projects/*/locations/*/retiredResources/*.



1073
1074
1075
1076
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 1073

class RetiredResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#original_resource::String (readonly)

Returns Output only. The full resource name of the original CryptoKey that was deleted in the format projects/*/locations/*/keyRings/*/cryptoKeys/*.

Returns:

  • (::String)

    Output only. The full resource name of the original CryptoKey that was deleted in the format projects/*/locations/*/keyRings/*/cryptoKeys/*.



1073
1074
1075
1076
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 1073

class RetiredResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_type::String (readonly)

Returns Output only. The resource type of the original deleted resource.

Returns:

  • (::String)

    Output only. The resource type of the original deleted resource.



1073
1074
1075
1076
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 1073

class RetiredResource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end