Module: Google::Cloud::Kms::Inventory::V1::FallbackScope
- Defined in:
- proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb
Overview
Specifies the scope to use if the organization service agent is not configured.
Constant Summary collapse
- FALLBACK_SCOPE_UNSPECIFIED =
Unspecified scope type.
0- FALLBACK_SCOPE_PROJECT =
If set to
FALLBACK_SCOPE_PROJECT, the API will fall back to using key's project as request scope if the kms organization service account is not configured. 1