Class: Google::Cloud::Kms::Inventory::V1::Warning
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::Inventory::V1::Warning
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb
Overview
A warning message that indicates potential problems with the response data.
Defined Under Namespace
Modules: WarningCode
Instance Attribute Summary collapse
-
#display_message ⇒ ::String
The literal message providing context and details about the warnings.
-
#warning_code ⇒ ::Google::Cloud::Kms::Inventory::V1::Warning::WarningCode
The specific warning code for the displayed message.
Instance Attribute Details
#display_message ⇒ ::String
Returns The literal message providing context and details about the warnings.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 236 class Warning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different types of warnings that can be returned to the user. # The display_message contains detailed information regarding the # warning_code. module WarningCode # Default value. This value is unused. WARNING_CODE_UNSPECIFIED = 0 # Indicates that the caller or service agent lacks necessary permissions # to view some of the requested data. The response may be partial. # Example: # - KMS organization service agent \\{service_agent_name} lacks the # `cloudasset.assets.searchAllResources` permission on the scope. INSUFFICIENT_PERMISSIONS_PARTIAL_DATA = 1 # Indicates that a resource limit has been exceeded, resulting in partial # data. Example: # - The project has more than 10,000 assets (resources, # crypto keys, key handles, IAM policies, etc). RESOURCE_LIMIT_EXCEEDED_PARTIAL_DATA = 2 # Indicates that the project exists outside of an organization resource. # Thus the analysis is only done for the project level data and results # might be partial. ORG_LESS_PROJECT_PARTIAL_DATA = 3 end end |
#warning_code ⇒ ::Google::Cloud::Kms::Inventory::V1::Warning::WarningCode
Returns The specific warning code for the displayed message.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'proto_docs/google/cloud/kms/inventory/v1/key_tracking_service.rb', line 236 class Warning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different types of warnings that can be returned to the user. # The display_message contains detailed information regarding the # warning_code. module WarningCode # Default value. This value is unused. WARNING_CODE_UNSPECIFIED = 0 # Indicates that the caller or service agent lacks necessary permissions # to view some of the requested data. The response may be partial. # Example: # - KMS organization service agent \\{service_agent_name} lacks the # `cloudasset.assets.searchAllResources` permission on the scope. INSUFFICIENT_PERMISSIONS_PARTIAL_DATA = 1 # Indicates that a resource limit has been exceeded, resulting in partial # data. Example: # - The project has more than 10,000 assets (resources, # crypto keys, key handles, IAM policies, etc). RESOURCE_LIMIT_EXCEEDED_PARTIAL_DATA = 2 # Indicates that the project exists outside of an organization resource. # Thus the analysis is only done for the project level data and results # might be partial. ORG_LESS_PROJECT_PARTIAL_DATA = 3 end end |