Class: Google::Cloud::Kms::V1::ChecksummedData
- Inherits:
-
Object
- Object
- Google::Cloud::Kms::V1::ChecksummedData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/kms/v1/resources.rb
Overview
Data with integrity verification field.
Instance Attribute Summary collapse
-
#crc32c_checksum ⇒ ::Google::Protobuf::Int64Value
Integrity verification field.
-
#data ⇒ ::String
Raw Data.
Instance Attribute Details
#crc32c_checksum ⇒ ::Google::Protobuf::Int64Value
Returns Integrity verification field. A CRC32C
checksum of the returned
ChecksummedData.data. An
integrity check of
ChecksummedData.data can be
performed by computing the CRC32C checksum of
ChecksummedData.data and
comparing your results to this field. Discard the response in case of
non-matching checksum values, and perform a limited number of retries. A
persistent mismatch may indicate an issue in your computation of the CRC32C
checksum. Note: This field is defined as int64 for reasons of compatibility
across different languages. However, it is a non-negative integer, which
will never exceed 2^32-1, and can be safely downconverted to uint32 in
languages that support this type.
723 724 725 726 |
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 723 class ChecksummedData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#data ⇒ ::String
Returns Raw Data.
723 724 725 726 |
# File 'proto_docs/google/cloud/kms/v1/resources.rb', line 723 class ChecksummedData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |